/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.service.jpa;

import java.math.BigInteger;
import java.util.List;

import javax.persistence.Query;

import org.hedgecode.chess.domain.Author;
import org.hedgecode.chess.domain.Etude;
import org.hedgecode.chess.domain.EtudeType;
import org.hedgecode.chess.service.EtudeService;

/**
 *
 *
 * @author Dmitry Samoshin aka gotty
 */
public class JpaEtudeService extends JpaDomainService<Etude> implements EtudeService {

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public List<Etude> findAll() {
        return getEntityManager().createNamedQuery(
                Etude.FIND_ALL
        ).getResultList();
    }

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public Etude findById(Long id) {
        Query query = getEntityManager().createNamedQuery(
                Etude.FIND_BY_ID
        );
        query.setParameter(Etude.ID_PARAMETER, id);
        return (Etude) query.getSingleResult();
    }

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public List<Etude> findByHash(BigInteger hash) {
        Query query = getEntityManager().createNamedQuery(
                Etude.FIND_BY_HASH
        );
        query.setParameter(Etude.HASH_PARAMETER, hash);
        return query.getResultList();
    }

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public List<Etude> findByType(EtudeType etudeType) {
        Query query = getEntityManager().createNamedQuery(
                Etude.FIND_BY_TYPE
        );
        query.setParameter(Etude.TYPE_PARAMETER, etudeType);
        return query.getResultList();
    }

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public List<Etude> findByAuthor(Author author) {
        Query query = getEntityManager().createNamedQuery(
                Etude.FIND_BY_AUTHOR
        );
        query.setParameter(Etude.AUTHOR_PARAMETER, author);
        return query.getResultList();
    }

    @Override
    @SuppressWarnings(
            "unchecked"
    )
    public List<Etude> findByBlob(byte[] blob) {
        Query query = getEntityManager().createNamedQuery(
                Etude.FIND_BY_BLOB
        );
        query.setParameter(Etude.BLOB_PARAMETER, blob);
        return query.getResultList();
    }

}
