/*
 * Copyright (c) 2018-2019. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.img;

import java.util.ResourceBundle;

/**
 * Image load/build Exception.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class ImageException extends Exception {

    private static final ResourceBundle LOCALE_BUNDLE =
            ResourceBundle.getBundle(ImageConstants.LOCALE_BUNDLE_FILE);

    private String localeKey;
    private String message;

    public ImageException(String localeKey) {
        this.localeKey = localeKey;
        this.message = null;
    }

    public ImageException(String localeKey, String message) {
        this.localeKey = localeKey;
        this.message = message;
    }

    public String getLocaleKey() {
        return localeKey;
    }

    public String getMessage() {
        StringBuilder sb = new StringBuilder();
        sb.append(LOCALE_BUNDLE.getString(localeKey));
        if (message != null)
            sb.append(": [").append(message).append("]");
        return sb.toString();
    }

}
