/*
 * Copyright (c) 2018-2019. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.img.board;

import java.awt.image.BufferedImage;
import java.util.Objects;

/**
 * Storage class for set of images of chess board squares.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class SquarePair<T> {

    private final T dark;
    private final T light;

    private SquarePair(T dark, T light) {
        this.dark = dark;
        this.light = light;
    }

    public T getDark() {
        return dark;
    }

    public T getLight() {
        return light;
    }

    public boolean isFilled() {
        if (this.dark == null || this.light == null) {
            return false;
        }
        return true;
    }

    @Override
    public boolean equals(Object o) {
        if (!(o instanceof SquarePair)) {
            return false;
        }
        SquarePair<?> that = (SquarePair<?>) o;

        return Objects.equals(this.dark, that.dark)
                && Objects.equals(this.light, that.light);
    }

    @Override
    public int hashCode() {
        return (dark == null ? 0 : dark.hashCode())
                ^ (light == null ? 0 : light.hashCode());
    }

    public static SquarePair<BufferedImage> create(BufferedImage dark, BufferedImage light) {
        return new SquarePair<>(dark, light);
    }

}
