/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.hedgefish;

import org.hedgecode.chess.uci.Engine;
import org.hedgecode.chess.uci.DebugMode;
import org.hedgecode.chess.uci.Transmitter;

/**
 * Hedgefish UCI Engine.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class HedgefishEngine implements Engine {

    private static final String HEDGEFISH_COPYIGHT = "Hedgefish 0.1 (c) 2018 Hedgecode, D.Samoshin aka gotty";

    private Transmitter<HedgefishCommand> transmitter;

    private DebugMode debugMode;

    HedgefishEngine() {
        transmitter = new HedgefishTransmitter();
        debugMode = DebugMode.OFF;
    }

    public Transmitter<HedgefishCommand> transmitter() {
        return transmitter;
    }

    public void command(HedgefishCommand command) {
        transmitter.addCommand(command);
    }


    @Override
    public void init() {

    }

    @Override
    public void debug(DebugMode mode) {
        debugMode = mode;
    }

    @Override
    public void isReady() {

    }

    @Override
    public void go() {

    }

    @Override
    public void stop() {

    }

    @Override
    public void ponderhit() {

    }

    @Override
    public void quit() {
        transmitter.stop();
    }

}
