/*
 * Copyright (c) 2018-2019. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.qrcode.zip;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.zip.InflaterInputStream;

import org.hedgecode.chess.qrcode.ChessQRCodeConstants;
import org.hedgecode.chess.qrcode.ChessQRCodeException;

/**
 *
 *
 * @author Dmitry Samoshin aka gotty
 */
public class ZipContentInflater {

    public static String inflate(String zipContents) throws ChessQRCodeException {
        byte[] zipBytes = ZipContentUtils.base64Decode(zipContents);
        int length = ZipContentUtils.getZipLength(zipBytes);
        if (length > ZipContentUtils.getMaxContentLength()) {
            throw new ChessQRCodeException(
                    ChessQRCodeException.Type.PARSE, "zip.max.length.error"
            );
        }
        byte[] resultBytes = new byte[length];
        InflaterInputStream zin = new InflaterInputStream(
                new ByteArrayInputStream(
                        ZipContentUtils.getZipBytes(zipBytes)
                )
        );
        try {
            try {
                length = zin.read(resultBytes, 0, length); // todo : check length
            } finally {
                zin.close();
            }
        } catch (IOException e) {
            throw new ChessQRCodeException(
                    ChessQRCodeException.Type.PARSE, "zip.inflate.read.error", e.getMessage()
            );
        }
        return new String(
                resultBytes, 0, length, ChessQRCodeConstants.CHARSET
        );
    }

}
